==> haskell-warp-3.2.11.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.11.2
id: warp-3.2.11.2-6TIZU8HiI628nebZu7ZLor
key: warp-3.2.11.2-6TIZU8HiI628nebZu7ZLor
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.File
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.IORef Network.Wai.Handler.Warp.PackInt
                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
                Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Some
                Network.Wai.Handler.Warp.Timeout Network.Wai.Handler.Warp.Types
                Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
abi: 722c3a27b3fd0eed28fae8a60e36a732
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/warp-3.2.11.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/warp-3.2.11.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/warp-3.2.11.2
hs-libraries: HSwarp-3.2.11.2-6TIZU8HiI628nebZu7ZLor
depends:
    array-0.5.1.1 async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4
    auto-update-0.1.4-GAesfFmqoZzBz6e09kRyzb base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi containers-0.5.7.1
    ghc-prim-0.5.0.0 hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    http-date-0.0.6.1-Jpd6oqB2FgfHxNuwDmOMO1
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    http2-1.6.3-Ly4kqYWWNU8FdpSidNNOzB
    iproute-1.7.1-9hsGfRvggCmFA0ueZi5Sd9
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    simple-sendfile-0.2.25-DD8P3vuUuOYGeRr9aw9ky7
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    streaming-commons-0.1.17-6k51SJxMSKy6BYhtadRCnX
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ unix-2.7.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    vault-0.3.0.6-E6e1xEGSbzvJDLaCWzJ9Cl
    wai-3.2.1.1-1k6hSu2jHMHEfd9vQlBLrn
    word8-0.1.2-2E1SgvvAV2fK8vZPDHbRan
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.2.11.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.11.2
id: warp-3.2.11.2-A2csz5fviL3LDJCpEyPtB0
key: warp-3.2.11.2-A2csz5fviL3LDJCpEyPtB0
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.File
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.IORef Network.Wai.Handler.Warp.PackInt
                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
                Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Some
                Network.Wai.Handler.Warp.Timeout Network.Wai.Handler.Warp.Types
                Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
abi: e14d50295346b9ab9b6c8ceaa4e92a09
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/warp-3.2.11.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/warp-3.2.11.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/warp-3.2.11.2
hs-libraries: HSwarp-3.2.11.2-A2csz5fviL3LDJCpEyPtB0
depends:
    array-0.5.1.1 async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4
    auto-update-0.1.4-GAesfFmqoZzBz6e09kRyzb base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi containers-0.5.7.1
    ghc-prim-0.5.0.0 hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    http-date-0.0.6.1-Jpd6oqB2FgfHxNuwDmOMO1
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    http2-1.6.3-Ly4kqYWWNU8FdpSidNNOzB
    iproute-1.7.1-9hsGfRvggCmFA0ueZi5Sd9
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    simple-sendfile-0.2.25-DD8P3vuUuOYGeRr9aw9ky7
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    streaming-commons-0.1.17-6k51SJxMSKy6BYhtadRCnX
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ unix-2.7.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    vault-0.3.0.7-7ljhTnQetmMK9FZWfMdQzN
    wai-3.2.1.1-HegeDw2KVvNKTqaIBuqg9O
    word8-0.1.2-2E1SgvvAV2fK8vZPDHbRan
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
